@@ -3,7 +3,7 @@ package CPAN::Maker;
 use strict;
 use warnings;
 
-our $VERSION = '1.5.43';
+our $VERSION = '1.5.44';
 
 1;
 
@@ -27,7 +27,7 @@ CPAN::Maker - create a CPAN distribution
 
 Utility that is part of a toolchain to create a CPAN distribution.
 
-This utility should normally be called witht the C<--buildspec> option
+This utility should normally be called with the C<--buildspec> option
 specifying a YAML file that describes the distribution to be
 packaged. The toolchain can:
 
@@ -86,21 +86,42 @@ C<Makefile.PL> and before creating your CPAN distribution.
  -v, --version               version
      --version-from          module name that provide version
 
- This script is typically called with the C<--buildspec> option
- specifying a YAML file that contains the options for building a CPAN
- distribution.  Calling this script directly will only result in a
- C<Makefile.PL> being written to STDOUT.
+This script is typically called with the C<--buildspec> option
+specifying a YAML file that contains the options for building a CPAN
+distribution.  Calling this script directly will only result in a
+C<Makefile.PL> being written to STDOUT.
 
- When invoked with a buildspec it will parse the YAML file and call
- the bash script that actually creates the CPAN distribution.
+When invoked with a buildspec it will parse the YAML file and call
+the bash script that actually creates the CPAN distribution.
 
- Note: Set the environment variable C<PRESERVE_MAKEFILE> if you want
- the script to preserve the F<Makefile.PL>.  It will be copied to your
- current working directory.
+=head1 ENVIRONMENT VARIABLES
+
+=over 5
+
+=item PRESERVE_MAKEFILE
+
+Set this environment variable to a true value if you want
+the script to preserve the F<Makefile.PL>. It will be copied to your
+current working directory.
+
+=item SKIP_TESTS
+
+Set this environment variable a true value if you want
+the script to preserve the F<Makefile.PL>. It will be copied to your
+
+=item DEBUG
+
+Set this environment variable to set the debug level to verbose. The
+bash script will echo all commands run. This is useful for debugging
+problems that might arise if you "go off script"
+
+=back
 
  See https://github.com/rlauer6/make-cpan-dist.git for more documentation.
 
- Version: 1.5.43
+=head1 VERSION
+
+1.5.44
 
 =head1 USING THE BASH SCRIPT
 
@@ -123,8 +144,12 @@ that options like -l will be relative to the current directory.>
 
 Calling this utility directly with the C<-b> option will parse the
 buildspec and invoke the C<bash> script with all of the appropriate
-options.  This is probably the preferred way of using this
-toolchain. The format of the YAML build file is described below.
+options. This is the preferred way of using this toolchain. The format
+of the YAML build file is described below.
+
+I<IMPORTANT: All files specified in the F<buildspec.ym> file must be
+specified as absolute paths or they should be relative to the
+project's root directory, B<NOT THE CURRENT WORKING DIRECTORY!>>
 
 =head1 OPTION DETAILS
 
@@ -293,7 +318,7 @@ main module being packaged.
 
 Example:
 
-  version: 1.5.43
+  version: 1.5.44
   project:
     git: https://github.com/rlauer6/perl-Amazon-Credentials
     description: "AWS credentials discoverer"
@@ -593,7 +618,8 @@ in the distribution. Files should be relative to the project root.
 
 By default the script will look for dependencies in files named
 F<requires> and F<test-requires>.  These can be created automatically
-by the C<bash> script (C<make-cpan-dist>) or you can provide them.
+generated by the C<bash> script (C<make-cpan-dist>) or you can provide
+them.
 
 You can specify a different name for the files with the C<-r> and
 C<-t> options.
